@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- $Id: battstat_applet.c 10032 2006-10-24 06:46:58Z haip $
+ $Id: battstat_applet.c 11291 2009-02-17 00:21:22Z callum $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -37,12 +37,6 @@
 
 #include <gtk/gtk.h>
 
-#include <libgnome/libgnome.h>
-
-#include <libgnomeui/libgnomeui.h>
-
-#include <glade/glade.h>
-
 #include <panel-applet.h>
 #include <panel-applet-gconf.h>
 
@@ -321,7 +315,6 @@ static_global_initialisation (int no_hal, ProgressData *battstat)
 
   allocate_battery_colours();
   initialise_global_pixmaps();
-  glade_init();
   err = power_management_initialise (no_hal, status_change_callback);
 
   return err;
@@ -441,7 +434,7 @@ battery_full_notify (GtkWidget *applet)
 
 	/* XXX: it would be nice to pass this as a named icon */
 	notify_notification_set_icon_from_pixbuf (n, icon);
-	gdk_pixbuf_unref (icon);
+	g_object_unref (icon);
 
 	result = notify_notification_show (n, &error);
 	
@@ -711,7 +704,7 @@ update_tooltip( ProgressData *battstat, BatteryStatus *info )
                                  _("Battery status unknown"));
   }
 
-  gtk_tooltips_set_tip (battstat->tip, battstat->applet, tiptext, NULL);
+  gtk_widget_set_tooltip_text (battstat->applet, tiptext);
   g_free (tiptext);
 }
 
@@ -1151,9 +1144,6 @@ destroy_applet( GtkWidget *widget, ProgressData *battstat )
 {
   if (DEBUG) g_print("destroy_applet()\n");
 
-  if (battstat->about_dialog)
-    gtk_widget_destroy (battstat->about_dialog);
-
   if (battstat->prop_win)
     gtk_widget_destroy (GTK_WIDGET (battstat->prop_win));
 
@@ -1169,7 +1159,6 @@ destroy_applet( GtkWidget *widget, ProgressData *battstat )
   g_object_unref( G_OBJECT(battstat->status) );
   g_object_unref( G_OBJECT(battstat->percent) );
   g_object_unref( G_OBJECT(battstat->battery) );
-  g_object_unref( G_OBJECT(battstat->tip) );
 
   g_free( battstat );
 
@@ -1183,10 +1172,19 @@ void
 battstat_show_help( ProgressData *battstat, const char *section )
 {
   GError *error = NULL;
+  char *uri;
 
-  gnome_help_display_on_screen( "battstat", section,
-                                gtk_widget_get_screen( battstat->applet ),
-                                &error );
+  if (section)
+    uri = g_strdup_printf ("ghelp:battstat?%s", section);
+  else
+    uri = g_strdup ("ghelp:battstat");
+
+  gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (battstat->applet)),
+                uri,
+                gtk_get_current_event_time (),
+                &error);
+
+  g_free (uri);
 
   if( error )
   {
@@ -1238,7 +1236,6 @@ about_cb( BonoboUIComponent *uic, ProgressData *battstat, const char *verb )
 			/* false */ _("Legacy (non-HAL) backend enabled."));
 
   gtk_show_about_dialog( NULL,
-    "name",                _("Battery Charge Monitor"), 
     "version",             VERSION,
     "copyright",           "\xC2\xA9 2000 The Gnulix Society, "
                            "\xC2\xA9 2002-2005 Free Software Foundation and "
@@ -1563,12 +1560,12 @@ create_layout(ProgressData *battstat)
      reference to each widget.  This adds a real reference to each widget
      and "sinks" the floating reference.
   */
-  gtk_widget_ref( battstat->status );
-  gtk_widget_ref( battstat->percent );
-  gtk_widget_ref( battstat->battery );
-  gtk_object_sink( GTK_OBJECT( battstat->status ) );
-  gtk_object_sink( GTK_OBJECT( battstat->percent ) );
-  gtk_object_sink( GTK_OBJECT( battstat->battery ) );
+  g_object_ref( battstat->status );
+  g_object_ref( battstat->percent );
+  g_object_ref( battstat->battery );
+  g_object_ref_sink( GTK_OBJECT( battstat->status ) );
+  g_object_ref_sink( GTK_OBJECT( battstat->percent ) );
+  g_object_ref_sink( GTK_OBJECT( battstat->battery ) );
 
   /* Let reconfigure_layout know that the table is currently empty. */
   battstat->layout.status = LAYOUT_NONE;
@@ -1579,15 +1576,6 @@ create_layout(ProgressData *battstat)
   gtk_container_add (GTK_CONTAINER (battstat->applet), battstat->table);
   gtk_widget_show_all (battstat->applet);
 
-  /* Set up the tooltip widget (which we will fill in later). */
-  battstat->tip = gtk_tooltips_new ();
-  g_object_ref (battstat->tip);
-  gtk_object_sink (GTK_OBJECT (battstat->tip));
-  gtk_tooltips_set_tip (battstat->tip,
-			battstat->applet,
-			"",
-			NULL);
-
   /* Attach all sorts of signals to the applet. */
   g_signal_connect(G_OBJECT(battstat->applet),
                    "destroy",
@@ -1619,6 +1607,8 @@ battstat_applet_fill (PanelApplet *applet)
 
   if (DEBUG) g_print("main()\n");
 
+  g_set_application_name (_("Battery Charge Monitor"));
+
   gtk_window_set_default_icon_name ("battery");
   
   panel_applet_add_preferences (applet, "/schemas/apps/battstat-applet/prefs",
@@ -1638,7 +1628,6 @@ battstat_applet_fill (PanelApplet *applet)
   battstat->horizont = TRUE;
   battstat->battery_low_dialog = NULL;
   battstat->battery_low_label = NULL;
-  battstat->about_dialog = NULL;
   battstat->pixgc = NULL;
   battstat->timeout = -1;
   battstat->timeout_id = 0;
