@@ -1,4 +1,4 @@
-/* $Id: gweather-dialog.c 10593 2008-01-14 19:55:40Z callum $ */
+/* $Id: gweather-dialog.c 11289 2009-02-16 23:48:56Z callum $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -19,7 +19,6 @@
 #include <assert.h>
 
 #include <gconf/gconf-client.h>
-#include <gnome.h>
 
 #define GWEATHER_I_KNOW_THIS_IS_UNSTABLE
 
@@ -137,7 +136,10 @@ static void
 link_cb (GtkButton *button,
          gpointer data)
 {
-    gnome_url_show("http://www.weather.com/", NULL);
+    gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (button)),
+		    "http://www.weather.com/",
+		    gtk_get_current_event_time (),
+		    NULL);
 }
 
 static gchar*
@@ -549,7 +551,7 @@ gweather_dialog_create (GWeatherDialog *dialog)
 
       radar_link_btn = gtk_button_new_with_mnemonic (_("_Visit Weather.com"));
       set_access_namedesc (radar_link_btn, _("Visit Weather.com"), _("Click to Enter Weather.com"));
-      gtk_widget_set_usize(radar_link_btn, 450, -2);
+      gtk_widget_set_size_request (radar_link_btn, 450, -2);
       gtk_widget_show (radar_link_btn);
       if (!gweather_gconf_get_bool (gw_applet->gconf, "use_custom_radar_url", NULL))
           gtk_container_add (GTK_CONTAINER (radar_link_alignment), radar_link_btn);
