@@ -1,4 +1,4 @@
-/* $Id: main.c 10593 2008-01-14 19:55:40Z callum $ */
+/* $Id: main.c 11220 2009-01-25 23:43:11Z callum $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -10,9 +10,9 @@
  *
  */
 
-#  include <config.h>
-
-#include <gnome.h>
+#include <glib.h>
+#include <config.h>
+#include <gtk/gtk.h>
 #include <panel-applet.h>
 
 #define GWEATHER_I_KNOW_THIS_IS_UNSTABLE
