@@ -28,10 +28,11 @@
 #include <pty.h>
 #endif
 #include <sys/poll.h>
+#include <sys/stat.h>
 #include <sys/types.h>
 #include <sys/wait.h>
 #include <libxml/tree.h>
-#include <glade/glade.h>
+#include <errno.h>
 
 #ifdef __FreeBSD__
 #include <sys/ioctl.h>
@@ -53,7 +54,7 @@ typedef struct _ModemAppletPrivate ModemAppletPrivate;
 struct _ModemAppletPrivate
 {
   /* applet UI stuff */
-  GladeXML     *xml;
+  GtkBuilder   *builder;
   GtkIconTheme *icon_theme;
   GdkPixbuf    *icon;
   GtkWidget    *image;
@@ -178,25 +179,26 @@ modem_applet_init (ModemApplet *applet)
 
   priv = MODEM_APPLET_GET_PRIVATE (applet);
 
-  priv->xml = glade_xml_new (GNOME_GLADEDIR "/modemlights.glade", NULL, NULL);
+  priv->builder = gtk_builder_new ();
+  gtk_builder_add_from_file (priv->builder, GTK_BUILDERDIR "/modemlights.ui", NULL);
   priv->icon = NULL;
   priv->icon_theme = gtk_icon_theme_get_default ();
   priv->image = gtk_image_new ();
 
-  priv->auth_dialog       = glade_xml_get_widget (priv->xml, "auth_dialog");
-  priv->auth_dialog_label = glade_xml_get_widget (priv->xml, "auth_dialog_label");
-  priv->auth_dialog_entry = glade_xml_get_widget (priv->xml, "auth_dialog_entry");
+  priv->auth_dialog       = GTK_WIDGET (gtk_builder_get_object (priv->builder, "auth_dialog"));
+  priv->auth_dialog_label = GTK_WIDGET (gtk_builder_get_object (priv->builder, "auth_dialog_label"));
+  priv->auth_dialog_entry = GTK_WIDGET (gtk_builder_get_object (priv->builder, "auth_dialog_entry"));
 
-  priv->report_window          = glade_xml_get_widget (priv->xml, "report_window");
-  priv->report_window_image    = glade_xml_get_widget (priv->xml, "report_window_image");
-  priv->report_window_progress = glade_xml_get_widget (priv->xml, "report_window_progress");
+  priv->report_window          = GTK_WIDGET (gtk_builder_get_object (priv->builder, "report_window"));
+  priv->report_window_image    = GTK_WIDGET (gtk_builder_get_object (priv->builder, "report_window_image"));
+  priv->report_window_progress = GTK_WIDGET (gtk_builder_get_object (priv->builder, "report_window_progress"));
 
   g_signal_connect (G_OBJECT (priv->report_window), "delete-event",
 		    G_CALLBACK (gtk_widget_hide), NULL);
 
   pixbuf = gtk_icon_theme_load_icon (priv->icon_theme, "gnome-modem-monitor-applet", 48, 0, NULL);
   gtk_image_set_from_pixbuf (GTK_IMAGE (priv->report_window_image), pixbuf);
-  gdk_pixbuf_unref (pixbuf);
+  g_object_unref (pixbuf);
 
   priv->configured = FALSE;
   priv->enabled = FALSE;
@@ -264,7 +266,7 @@ modem_applet_change_background (PanelApplet *app,
   gtk_widget_set_style (GTK_WIDGET (applet), NULL);
   rc_style = gtk_rc_style_new ();
   gtk_widget_modify_style (GTK_WIDGET (applet), rc_style);
-  gtk_rc_style_unref (rc_style);
+  g_object_unref (rc_style);
 
   switch (type)
     {
@@ -458,7 +460,7 @@ read_xml (ModemApplet *applet, gboolean show_report)
   /* if show_report, create pulse timeout and show window */
   if (show_report)
     {
-      priv->progress_id = gtk_timeout_add (200, (GSourceFunc) pulse_progressbar, priv->report_window_progress);
+      priv->progress_id = g_timeout_add (200, (GSourceFunc) pulse_progressbar, priv->report_window_progress);
       gtk_window_set_screen (GTK_WINDOW (priv->report_window), gtk_widget_get_screen (GTK_WIDGET (applet)));
       gtk_widget_show (priv->report_window);
     }
@@ -1030,9 +1032,10 @@ on_modem_applet_help_clicked (BonoboUIComponent *uic,
 			      ModemApplet       *applet,
 			      const char        *verb)
 {
-  gnome_help_display_on_screen ("modemlights", NULL,
-				gtk_widget_get_screen (GTK_WIDGET (applet)),
-				NULL);
+  gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (applet)),
+		"ghelp:modemlights",
+		gtk_get_current_event_time (),
+		NULL);
 }
 
 static gboolean
