@@ -137,7 +137,7 @@ void
 load_graph_unalloc (LoadGraph *g)
 {
     guint i;
-	
+
     if (!g->allocated)
 		return;
 
@@ -245,12 +245,10 @@ static void
 load_graph_destroy (GtkWidget *widget, gpointer data_ptr)
 {
     LoadGraph *g = (LoadGraph *) data_ptr;
-	
+
     load_graph_stop (g);
-    if (g->tooltips) {
-    		g_object_unref (g->tooltips);
-		g->tooltips = NULL;
-    }
+    netspeed_delete(g->netspeed_in);
+    netspeed_delete(g->netspeed_out);
 
     gtk_widget_destroy(widget);
 }
@@ -276,12 +274,12 @@ load_graph_load_config (LoadGraph *g)
 	for (i = 0; i < g->n; i++)
 	{
 		g_snprintf(name, sizeof(name), "%s_color%u", g->name, i);
-		temp = g_strdup_printf("%s", panel_applet_gconf_get_string(g->multiload->applet, name, NULL));
+		temp = panel_applet_gconf_get_string(g->multiload->applet, name, NULL);
+		if (!temp)
+			temp = g_strdup ("#000000");
 		gdk_color_parse(temp, &(g->colors[i]));
 		g_free(temp);
 	}
-
-	return;	
 }
 
 LoadGraph *
@@ -293,7 +291,8 @@ load_graph_new (MultiloadApplet *ma, guint n, const gchar *label,
     PanelAppletOrient orient;
     
     g = g_new0 (LoadGraph, 1);
-
+    g->netspeed_in = netspeed_new(g);
+    g->netspeed_out = netspeed_new(g);
     g->visible = visible;
     g->name = name;
     g->n = n;
@@ -352,10 +351,6 @@ load_graph_new (MultiloadApplet *ma, guint n, const gchar *label,
     else
         gtk_widget_set_size_request (g->main_widget, g->size, -1);
 
-    g->tooltips = gtk_tooltips_new();
-    g_object_ref (g->tooltips);
-    gtk_object_sink (GTK_OBJECT (g->tooltips));
-
     g->disp = gtk_drawing_area_new ();
     gtk_widget_set_events (g->disp, GDK_EXPOSURE_MASK |
 				    GDK_ENTER_NOTIFY_MASK |
@@ -373,7 +368,7 @@ load_graph_new (MultiloadApplet *ma, guint n, const gchar *label,
 	
     gtk_box_pack_start (GTK_BOX (g->box), g->disp, TRUE, TRUE, 0);    
     gtk_widget_show_all(g->box);
-    
+
     return g;
 }
 
